@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-__version__ = "1.3.0"
+__version__ = "1.4.1"
 
 from abc import abstractmethod
 
@@ -9,9 +9,9 @@ from sensor_state_data import SensorUpdate
 from sensor_state_data.data import DeviceClass, SensorData
 from sensor_state_data.units import SIGNAL_STRENGTH_DECIBELS_MILLIWATT
 
-RSSI_KEY = "rssi"
+SIGNAL_STRENGTH_KEY = DeviceClass.SIGNAL_STRENGTH.value
 
-__all__ = ["BluetoothData", "RSSI_KEY"]
+__all__ = ["BluetoothData", "SIGNAL_STRENGTH"]
 
 
 class BluetoothData(SensorData):
@@ -29,15 +29,16 @@ class BluetoothData(SensorData):
     def update(self, data: BluetoothServiceInfo) -> SensorUpdate:
         """Update a device."""
         self._start_update(data)
-        self.update_rssi(data.rssi)
+        self.update_signal_strength(data.rssi)
         return self._finish_update()
 
-    def update_rssi(self, native_value: int | float) -> None:
-        """Quick update for an rssi sensor."""
-        self.update_sensor(
-            key=RSSI_KEY,
-            native_unit_of_measurement=SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
-            native_value=native_value,
-            device_class=DeviceClass.SIGNAL_STRENGTH,
-            device_id=self.primary_device_id,
-        )
+    def update_signal_strength(self, native_value: int | float) -> None:
+        """Quick update for an signal strength sensor."""
+        for device_id in self._device_id_to_type:
+            self.update_sensor(
+                key=DeviceClass.SIGNAL_STRENGTH.value,
+                native_unit_of_measurement=SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
+                native_value=native_value,
+                device_class=DeviceClass.SIGNAL_STRENGTH,
+                device_id=device_id,
+            )
